# $Id: xchain-gccstage1.make,v 0.3.2.1 2002/09/11 22:00:00 robert Exp $
#
# (c) 2002 by Pengutronix e.K., Hildesheim, Germany
# See CREDITS for details about who has contributed to this project. 
#
# For further information about the PTXDIST project and license conditions
# see the README file.
#

#
# We provide this package
#
ifeq (y,$(PTXCONF_BUILD_CROSSCHAIN))
PACKAGES += xchain-gccstage1
endif

#
# Paths and names 
#
GCC_PREFIX		= arm-linux-
GCC			= gcc-2.95.3
GCC_URL			= ftp://ftp.gnu.org/pub/gnu/gcc/$(GCC).tar.gz
GCC_SOURCE		= $(SRCDIR)/$(GCC).tar.gz
GCC_DIR			= $(BUILDDIR)/$(GCC)
GCC_STAGE1_DIR		= $(BUILDDIR)/$(GCC)-$(GCC_PREFIX)stage1
GCC_STAGE2_DIR		= $(BUILDDIR)/$(GCC)-$(GCC_PREFIX)stage2
GCC_EXTRACT		= gzip -dc

GCC_ARMPATCH		= gcc-2.95.3.diff
GCC_ARMPATCH_URL	= ftp://ftp.arm.linux.org.uk/pub/armlinux/toolchain/src-2.95.3/gcc-2.95.3.diff.bz2
GCC_ARMPATCH_SOURCE	= $(SRCDIR)/$(GCC_ARMPATCH).bz2
GCC_ARMPATCH_DIR	= $(GCC_DIR)
GCC_ARMPATCH_EXTRACT	= bzip2 -dc

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

xchain-gccstage1_get: $(STATEDIR)/xchain-gccstage1.get

xchain-gccstage1_get_deps =  $(GCC_SOURCE)
ifeq (y,$(PTXCONF_ARCH_ARM))
xchain-gccstage1_get_deps += $(GCC_ARMPATCH_SOURCE)
endif

$(STATEDIR)/xchain-gccstage1.get: $(xchain-gccstage1_get_deps)
	touch $@

$(GCC_SOURCE): 
	@echo
	@echo --------------------
	@echo "xchain-gccstage1.get (gcc source)"
	@echo --------------------
	@echo
	wget -P $(SRCDIR) $(PASSIVEFTP) $(GCC_URL)

$(GCC_ARMPATCH_SOURCE): 
	@echo
	@echo --------------------
	@echo "xchain-gccstage1.get (ARM patch)"
	@echo --------------------
	@echo
	wget -P $(SRCDIR) $(PASSIVEFTP) $(GCC_ARMPATCH_URL)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

xchain-gccstage1_extract: $(STATEDIR)/xchain-gccstage1.extract

$(STATEDIR)/xchain-gccstage1.extract: $(STATEDIR)/xchain-gccstage1.get
	@echo
	@echo ------------------------
	@echo xchain-gccstage1.extract 
	@echo ------------------------
	@echo
	$(GCC_EXTRACT) $(GCC_SOURCE) | tar -C $(BUILDDIR) -xf -
	cd $(GCC_DIR) && 								\
		$(GCC_ARMPATCH_EXTRACT) $(GCC_ARMPATCH_SOURCE) | patch -p1
	perl -i -p -e 									\
		's/^(TARGET_LIBGCC2_CFLAGS.*)/$$1 -Dinhibit_libc -D__gthr_posix_h/' 	\
		$(GCC_DIR)/gcc/config/arm/t-linux
	touch $@

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

xchain-gccstage1_prepare: $(STATEDIR)/xchain-gccstage1.prepare

xchain-gccstage1_prepare_deps =  $(STATEDIR)/xchain-binutils.install
xchain-gccstage1_prepare_deps += $(STATEDIR)/xchain-gccstage1.extract
xchain-gccstage1_prepare_deps += $(STATEDIR)/xchain-kernel.extract

$(STATEDIR)/xchain-gccstage1.prepare: $(xchain-gccstage1_prepare_deps)
	@echo
	@echo ------------------------
	@echo xchain-gccstage1.prepare 
	@echo ------------------------
	@echo
	[ -d $(GCC_STAGE1_DIR) ] || mkdir $(GCC_STAGE1_DIR)
	#
	# copy some header files
	# 
	mkdir -p $(PTXCONF_CROSSCHAIN_PREFIX)/asm-arm/include
	cp -a   $(KERNEL_DIR)/include/asm-arm                           \
                $(PTXCONF_CROSSCHAIN_PREFIX)/asm-arm/include
	cp -a   $(KERNEL_DIR)/include/linux                             \
                $(PTXCONF_CROSSCHAIN_PREFIX)/asm-arm/include
	ln -sf  $(PTXCONF_CROSSCHAIN_PREFIX)/asm-arm/include/asm-arm \
                $(PTXCONF_CROSSCHAIN_PREFIX)/asm-arm/include/asm
	ln -sf	asm-arm	$(PTXCONF_CROSSCHAIN_PREFIX)/asm
	#
	# configure 
	#
	cd $(GCC_STAGE1_DIR) && 					\
		PATH=$$PATH:$(PTXCONF_CROSSCHAIN_PREFIX)/bin		\
	  	AR=arm-linux-ar						\
		RANLIB=arm-linux-ranlib					\
	     	CC=$(HOSTCC)						\
		$(GCC_DIR)/configure 					\
			--target=arm-linux				\
			--prefix=$(PTXCONF_CROSSCHAIN_PREFIX)	\
			--enable-target-optspace			\
			--disable-nls					\
			--with-gnu-ld					\
			--disable-shared				\
			--enable-languages=c				\
			--with-headers=$(KERNEL_DIR)/include		\
			--with-headers=$(PTXCONF_CROSSCHAIN_PREFIX)/asm/include
	touch $@

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

xchain-gccstage1_compile: $(STATEDIR)/xchain-gccstage1.compile

$(STATEDIR)/xchain-gccstage1.compile: 					\
	$(STATEDIR)/xchain-gccstage1.prepare
	@echo
	@echo ------------------------
	@echo xchain-gccstage1.compile 
	@echo ------------------------
	@echo
	PATH=$(PATH):$(PTXCONF_CROSSCHAIN_PREFIX)/bin make -C $(GCC_STAGE1_DIR)
	touch $@

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

xchain-gccstage1_install: $(STATEDIR)/xchain-gccstage1.install

$(STATEDIR)/xchain-gccstage1.install: $(STATEDIR)/xchain-gccstage1.compile
	@echo
	@echo ------------------------
	@echo xchain-gccstage1.install 
	@echo ------------------------
	@echo
	PATH=$(PATH):$(PTXCONF_CROSSCHAIN_PREFIX)/bin make -C $(GCC_STAGE1_DIR) install
	touch $@

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

xchain-gccstage1_clean:
	rm -fr $(GCC_STAGE1_DIR) $(STATEDIR)/xchain-gccstage1.* $(GCC_DIR)


# vim: syntax=make
